"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseStackTrace = exports.parseChromeIe = exports.parseFirefox = void 0;
function createRawFrame(raw) {
    return {
        column: -1,
        fileName: "",
        line: -1,
        name: "",
        raw: raw,
        sourceColumn: -1,
        sourceFileName: "",
        sourceLine: -1,
        type: "",
    };
}
var FIREFOX = /([^@]+|^)@(.*):(\d+):(\d+)/;
function parseFirefox(stack) {
    return stack
        .split("\n")
        .filter(Boolean)
        .map(function (str) {
        var match = str.match(FIREFOX);
        if (!match) {
            return createRawFrame(str);
        }
        var line = match[3] ? +match[3] : -1;
        var column = match[4] ? +match[4] : -1;
        var fileName = match[2] ? match[2] : "";
        return {
            line: line,
            column: column,
            type: match[0] ? "" : "native",
            fileName: fileName,
            name: (match[1] || "").trim(),
            raw: str,
            sourceColumn: -1,
            sourceFileName: "",
            sourceLine: -1,
        };
    });
}
exports.parseFirefox = parseFirefox;
var CHROME_IE = /^\s*at\s([a-zA-Z0-9_.\[\] <>]*).*?\s?\((.*?):(\d+):(\d+)(?:\s<-\s(.+):(\d+):(\d+))?\)/;
var CHROME_IE_SHORT = /^\s*at\s(.*):(\d+):(\d+)/;
var CHROME_IE_NATIVE = /\s*at\s<(.*)>\s*/;
var CHROME_IE_DETECTOR = /\s*at\s.+/;
function parseChromeIe(stack) {
    var lines = stack.split("\n");
    // Many frameworks mess with error.stack. So we use this check
    // to find the first line of the actual stack
    var start = lines.findIndex(function (line) { return CHROME_IE_DETECTOR.test(line); });
    if (start === -1) {
        return [];
    }
    var frames = [];
    for (var i = start; i < lines.length; i++) {
        var str = lines[i];
        // Sometimes frameworks will put an empty line inbetween
        if (!str)
            continue;
        var frame = createRawFrame(str);
        var match = str.match(CHROME_IE);
        if (match) {
            frame.name = (match[1] || "").trim();
            frame.line = match[3] ? +match[3] : -1;
            frame.column = match[4] ? +match[4] : -1;
            frame.fileName = match[2] ? match[2] : "";
            frame.sourceLine = match[6] ? +match[6] : -1;
            frame.sourceColumn = match[7] ? +match[7] : -1;
            frame.sourceFileName = match[5] ? match[5] : "";
            frames.push(frame);
            continue;
        }
        // Short form
        var short = str.match(CHROME_IE_SHORT);
        if (short) {
            if (short[1])
                frame.fileName = short[1];
            if (short[2])
                frame.line = +short[2];
            if (short[3])
                frame.column = +short[3];
            frames.push(frame);
            continue;
        }
        var native = str.match(CHROME_IE_NATIVE);
        if (native) {
            frame.name = native[1];
            frame.type = "native";
            frames.push(frame);
            continue;
        }
        frames.push(frame);
    }
    return frames;
}
exports.parseChromeIe = parseChromeIe;
function parseStackTrace(stack) {
    if (FIREFOX.test(stack)) {
        return parseFirefox(stack);
    }
    return parseChromeIe(stack);
}
exports.parseStackTrace = parseStackTrace;
//# sourceMappingURL=index.js.map